Index: trunk/archive/pslib/include/psStats.h
===================================================================
--- trunk/archive/pslib/include/psStats.h	(revision 609)
+++ trunk/archive/pslib/include/psStats.h	(revision 671)
@@ -39,11 +39,11 @@
     double sampleUQ;			///< upper quartile of sample
     double sampleLQ;			///< lower quartile of sample
-    double robustMean;			///< robust mean of array
+    double robustMean;			///< robust mean of data
     int    robustMeanNvalues;		///< number of measurements used for robust mean
-    double robustMedian;		///< robust median of array
+    double robustMedian;		///< robust median of data
     int    robustMedianNvalues;		///< number of measurements used for robust median
-    double robustMode;			///< Robust mode of array
+    double robustMode;			///< Robust mode of data
     int    robustModeNvalues;		///< Number of measurements used for robust mode
-    double robustStdev;			///< robust standard deviation of array
+    double robustStdev;			///< robust standard deviation of data
     double robustUQ;			///< robust upper quartile
     double robustLQ;			///< robust lower quartile
@@ -53,29 +53,29 @@
     double clipSigma;			///< Nsigma used for clipping; user input
     int    clipIter;			///< Number of clipping iterations; user input
-    double min;				///< minimum data value in array
-    double max;				///< maximum data value in array
-    int    nValues;			///< number of data values in array
+    double min;				///< minimum data value in data
+    double max;				///< maximum data value in data
+    int    nValues;			///< number of data values in data
     psStatsOptions options;		///< bitmask of calculated values
 } psStats;
 
 
 /** Do Statistics on an array.  Returns a status value. \ingroup MathGroup */
 psStats *
-psArrayStats(psStats *stats,		///< stats structure defines stats to be calculated, how and result
-	     const psFloatArray *restrict myArray, ///< Array to be analysed
-	     const psIntArray *restrict maskArray, ///< Ignore elements where (maskArray & maskVal) != 0
-						   ///< May be NULL
-	     unsigned int maskVal	///< Only mask elements with one of these bits set in maskArray
-    );
+psVectorStats(psStats *stats,		///< stats structure defines stats to be calculated, how and result
+	     const psVector *restrict myArray, ///< Array to be analysed
+	     const psVector *restrict maskArray, ///< Ignore elements where (maskArray & maskVal) != 0
+					///< May be NULL
+	     unsigned int maskVal)	///< Only mask elements with one of these bits set in maskArray
+;
 
 /** Constructor */
 psStats *
-psStatsAlloc(psStatsOptions options	///< Statistics to measure
-    );
+psStatsAlloc(psStatsOptions options)	///< Statistics to measure
+;
 
 /** Destructor */
 void
-psStatsFree(psStats *restrict stats	///< Stats structure to destroy
-    );
+psStatsFree(psStats *restrict stats)	///< Stats structure to destroy
+;
 
 /***********************************************************************************************************/
@@ -83,6 +83,6 @@
 /** Histograms  */
 typedef struct {
-    const psFloatArray *restrict bounds; ///< Bounds for the bins
-    psIntArray *nums;			///< Number in each of the bins
+    const psVector *restrict bounds;	///< Bounds for the bins
+    psVector *nums;			///< Number in each of the bins
     const float minVal, maxVal;		///< Minimum and maximum values
     int minNum, maxNum;			///< Number below the minimum and above the maximum
@@ -94,25 +94,25 @@
 psHistogramAlloc(float lower,		///< Lower limit for the bins
 		 float upper,		///< Upper limit for the bins
-		 int n			///< Number of the bins
-    );
+		 int n)			///< Number of the bins
+;
 
 /** Generic constructor \ingroup MathGroup */
 psHistogram *
-psHistogramAllocGeneric(const psFloatArray *restrict bounds, ///< Bounds for the bins
+psHistogramAllocGeneric(const psVector *restrict bounds, ///< Bounds for the bins
 			float minVal,	///< Minimum value
-			float maxVal	///< Maximum value
-    );
+			float maxVal)	///< Maximum value
+;
 
 /** Destructor \ingroup MathGroup **/
 void
-psHistogramFree(psHistogram *restrict myHist ///< Histogram to destroy
-    );
+psHistogramFree(psHistogram *restrict myHist) ///< Histogram to destroy
+;
 
 
 /** Calculate a histogram \ingroup MathGroup **/
 psHistogram *
-psGetArrayHistogram(psHistogram *restrict myHist, ///< Histogram data
-		    const psFloatArray *restrict myArray ///< Array to analyse
-    );
+psVectorHistogram(psHistogram *restrict myHist, ///< Histogram data
+		  const psVector *restrict myArray) ///< Array to analyse
+;
 
 #endif
@@ -53,29 +53,29 @@
 
 
-/** Do Statistics on an array.  Returns a status value. \ingroup MathGroup */
+/** Do Statistics on a vector.  Returns a status value. \ingroup MathGroup */
 psStats *
